@@ -3,11 +3,13 @@ use POSIX qw(:sys_wait_h);
 use Proc::Fork;
 use Carp;
 use IO::Pipe;
+use IO::Handle;
 use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.025';
+
+our $VERSION = '0.1';
 
 
 sub new {
@@ -26,30 +28,30 @@ sub _init {
 
 
 sub max_kids {
-    my ($self,$n) = @_;
+    my ($self, $n) = @_;
     $n // return $self->{max_kids};
     $self->{max_kids} = $n;
 }
 
 
 sub ipc {
-    my ($self,$n) = @_;
+    my ($self, $n) = @_;
     $n // return $self->{ipc};
     $self->{ipc} = $n;
 }
 
 
 sub fmap {
-    my ($self,$code) = (shift,shift);
+    my ($self, $code) = (shift, shift);
     my %pids = ();
-    my @rs = (); #result set of child return values
+    my @rs = ();  # result set of child return values
     my $max = $self->max_kids;
     my $ipc = $self->ipc;
     for my $proc (@_) {
-        my $pipe = $ipc ? IO::Pipe->new : {}; #put this in your pipe, and smoke it
-        #max kids?
+        my $pipe = $ipc ? IO::Pipe->new : {};
+        # max kids?
         while ($max == keys %pids) {
-            #free a spot in queue when a process completes
+            # free a spot in queue when a process completes
             for my $pid (keys %pids) {
                 if (my $kid = waitpid($pid, WNOHANG)) {
                     delete $pids{$kid};
@@ -58,23 +60,22 @@ sub fmap {
             }
         }
         
-        run_fork { #processes fork here
+        run_fork {  # processes fork here
             parent {
-                $| = 1;
                 my $kid = shift;
                 $pids{$kid}++;
                 if ($ipc) {
                     $pipe->reader();
                     while(<$pipe>) {
-                        push @rs,$_;
+                        push @rs, $_;
                     }
                 }
             }
             child {
-                $| = 1;
                 my $rs = $code->($proc);
                 if ($ipc) {
                     $pipe->writer();
+                    $pipe->autoflush;
                     print $pipe $rs if defined $rs;
                 }
                 exit;
@@ -85,15 +86,14 @@ sub fmap {
         };
     }
     
-    1 while (wait() != -1); #wait for the stragglers to finish
+    1 while (wait() != -1);  # wait for the stragglers to finish
     return @rs;
 }
 
 
-
-
 1;
 
+
 __END__
 =head1 NAME
 
@@ -199,6 +199,10 @@ via IO::Pipe, a result set. Otherwise, it will continue on its merry way until
 either an error occurs that prevents a fork or all the subprocesses complete
 their tasks.
 
+=head1 TODO
+
+1. Timeouts
+
 =head1 SEE ALSO
 
 L<Proc::Fork>, L<IO::Pipe>
@@ -216,7 +220,7 @@ bug as I make changes.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Andrew Shapiro.
+Copyright 2019 Andrew Shapiro.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
